# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding field 'Location.default_location'
        db.add_column('locations_location', 'default_location', self.gf('django.db.models.fields.BooleanField')(default=False), keep_default=False)


    def backwards(self, orm):
        
        # Deleting field 'Location.default_location'
        db.delete_column('locations_location', 'default_location')


    models = {
        'locations.location': {
            'Meta': {'object_name': 'Location'},
            'city': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'country': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            'default_location': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'latitude': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'}),
            'longitude': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '50', 'db_index': 'True'}),
            'state': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'})
        }
    }

    complete_apps = ['locations']



from django.db import models

from geopy.geocoders import GoogleV3

from locations.choices import STATE_CHOICES, COUNTRY_CHOICES
from locations.utils import unique_slugify


class Location(models.Model):
    city = models.CharField(max_length=250)
    state = models.CharField(max_length=250, choices=STATE_CHOICES, blank=True, help_text="State is not required if you are out of the country.")
    country = models.CharField(max_length=50, choices=COUNTRY_CHOICES, blank=True)
    latitude = models.CharField(max_length=250, blank=True, editable=False)
    longitude = models.CharField(max_length=250, blank=True, editable=False)
    slug = models.SlugField(editable=False)
    default_location = models.BooleanField(default=False)

    def __str__(self):
        if self.state:
            return "{city}, {state}".format(city=self.city, state=self.state)
        else:
            return "{city}, {country}".format(city=self.city, country=self.country)

    def fetch_location(self):
        """
        Fetch the lat/long for a given string location.

        :return: lat, long
        """

        geolocator = GoogleV3()
        location = '{city} {state} {country}'.format(
            city=self.city,
            state=self.state,
            country=self.country
        )
        address, (latitude, longitude) = geolocator.geocode(location)

        return latitude, longitude

    def save(self, *args, **kwargs):
        slug_title = self.city + self.country
        unique_slugify(self, slug_title)

        latitude, longitude = self.fetch_location()

        self.latitude = latitude
        self.longitude = longitude

        super(Location, self).save(*args, **kwargs)



from setuptools import setup, find_packages

version = '0.2.2'

setup(name='django-locations-base',
      version=version,
      description="A simple locations app for Django",
      long_description=open("README.md", "r").read(),
      classifiers=[
          "Development Status :: 5 - Production/Stable",
          "Environment :: Web Environment",
          "Intended Audience :: End Users/Desktop",
          "Natural Language :: English",
          "Operating System :: OS Independent",
          "Framework :: Django",
          "Programming Language :: Python",
          "Programming Language :: Python :: 3",
          "Topic :: Internet :: WWW/HTTP :: Dynamic Content :: CGI Tools/Libraries",
          "Topic :: Utilities",
          "License :: OSI Approved :: MIT License",
          ],
      keywords='',
      author='Derek Stegelman',
      author_email='dstegelman@gmail.com',
      url='http://github.com/dstegelman/django-locations',
      license='MIT',
      packages=['locations',
                'locations.migrations'],
      include_package_data=True,
      zip_safe=False,
      install_requires=['django-localflavor>=1.1,<2.0', 'geopy>=1.9.1,<2.0']
    )


import unittest


from locations.models import Location


class TestLocations(unittest.TestCase):

    def test_geolocate(self):
        locate = Location(city='Loveland',
                          state='CO',
                          country='USA',
                          )

        locate.save()

        self.assertEqual(locate.latitude, 40.3977612)
        self.assertEqual(locate.longitude, -105.0749801)

    def test_state_unicode(self):
        locate = Location(city='Loveland',
                          state='CO',
                          country='USA',
                          )

        locate.save()

        self.assertEqual(locate.__str__(), 'Loveland, CO')

    def test_no_state_unicode(self):
        locate = Location(city='Rome',
                          country='Italy',
                          )

        locate.save()

        self.assertEqual(locate.__str__(), 'Rome, Italy')


# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Location'
        db.create_table('locations_location', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('city', self.gf('django.db.models.fields.CharField')(max_length=250)),
            ('state', self.gf('django.db.models.fields.CharField')(max_length=250, blank=True)),
            ('country', self.gf('django.db.models.fields.CharField')(max_length=50, blank=True)),
            ('latitude', self.gf('django.db.models.fields.CharField')(max_length=250, blank=True)),
            ('longitude', self.gf('django.db.models.fields.CharField')(max_length=250, blank=True)),
        ))
        db.send_create_signal('locations', ['Location'])


    def backwards(self, orm):
        
        # Deleting model 'Location'
        db.delete_table('locations_location')


    models = {
        'locations.location': {
            'Meta': {'object_name': 'Location'},
            'city': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'country': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'latitude': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'}),
            'longitude': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'}),
            'state': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'})
        }
    }

    complete_apps = ['locations']
